Package 'rspa'
| Title: |
Adapt Numerical Records to Fit (in)Equality Restrictions |
| Description: |
Minimally adjust the values of numerical records in a
data.frame, such that each record satisfies a predefined set of
equality and/or inequality constraints. The constraints can be
defined using the 'validate' package. The core algorithms have
recently been moved to the 'lintools' package, refer to
'lintools' for a more basic interface and access to a version
of the algorithm that works with sparse matrices. |
| Authors: |
Mark van der Loo |
| Maintainer: |
Mark van der Loo <[email protected]> |
| License: |
GPL-3 |
| Version: |
0.2.8 |
| Built: |
2026-05-07 05:45:30 UTC |
| Source: |
https://github.com/markvanderloo/rspa |
Help Index